@@ -311,6 +311,7 @@ class OutcomeCountEval(ABC):
                 direction, alignment, gens)
             for p in itertools.product(*iterators):
                 prev_gens, counts, weights = zip(*p)
+                counts = tuple(itertools.chain.from_iterable(counts))
                 prod_weight = math.prod(weights)
                 prev = self._eval_internal(direction, prev_alignment, prev_gens)
                 for prev_state, prev_weight in prev.items():
@@ -342,6 +343,7 @@ class OutcomeCountEval(ABC):
                     -direction, prev_alignment, prev_gens)
                 for p in itertools.product(*iterators):
                     gens, counts, weights = zip(*p)
+                    counts = tuple(itertools.chain.from_iterable(counts))
                     prod_weight = math.prod(weights)
                     state = self.next_state(prev_state, outcome, *counts)
                     if state is not icepool.Reroll:
@@ -355,9 +357,8 @@ class OutcomeCountEval(ABC):
 
 
 def _pop_gens(
-        side: int, alignment: Alignment,
-        gens: tuple[icepool.OutcomeCountGen,
-                    ...]) -> tuple[Any, Alignment, tuple]:
+    side: int, alignment: Alignment, gens: tuple[icepool.OutcomeCountGen, ...]
+) -> tuple[Any, Alignment, tuple['icepool.GenGenerator', ...]]:
     """Pops a single outcome from the gens.
 
     Returns:
@@ -370,18 +371,18 @@ def _pop_gens(
         outcome = max(
             gen.max_outcome() for gen in alignment_and_gens if gen.outcomes())
 
-        next_alignment, _, _ = next(alignment._pop_max(outcome))
+        next_alignment, _, _ = next(alignment._gen_max(outcome))
 
         return outcome, next_alignment, tuple(
-            gen._pop_max(outcome) for gen in gens)
+            gen._gen_max(outcome) for gen in gens)
     else:
         outcome = min(
             gen.min_outcome() for gen in alignment_and_gens if gen.outcomes())
 
-        next_alignment, _, _ = next(alignment._pop_min(outcome))
+        next_alignment, _, _ = next(alignment._gen_min(outcome))
 
         return outcome, next_alignment, tuple(
-            gen._pop_min(outcome) for gen in gens)
+            gen._gen_min(outcome) for gen in gens)
 
 
 class WrapFuncEval(OutcomeCountEval):
