@@ -5,7 +5,7 @@ import icepool.math
 import icepool.pool_cost
 import icepool.creation_args
 from icepool.counts import Counts
-from icepool.gen import OutcomeCountGen
+from icepool.gen import GenGenerator, OutcomeCountGen
 
 import itertools
 import math
@@ -68,6 +68,9 @@ class Pool(OutcomeCountGen):
                 `outcomes` or a single `int` to apply to all elements of
                 `outcomes`.
 
+        Raises:
+            ValueError for a `Deck` or `Die` argument. A pool of a single `Die`
+                should constructed as `Pool([die])`.
         """
         if isinstance(dice, Pool):
             if times == 1:
@@ -75,6 +78,17 @@ class Pool(OutcomeCountGen):
             else:
                 dice = dice._dice
 
+        if isinstance(dice, (icepool.Deck, icepool.Deal)):
+            raise ValueError(
+                f'A Pool cannot be constructed with a {type(dice).__name__} argument.'
+            )
+
+        if isinstance(dice, icepool.Die):
+            raise ValueError(
+                'A Pool cannot be constructed with a Die argument. '
+                'Use Pool([die]) or die.pool() to construct a pool of a single die.'
+            )
+
         dice, times = icepool.creation_args.itemize(dice, times)
         dice = tuple(icepool.Die([die]) for die in dice)
 
@@ -280,8 +294,7 @@ class Pool(OutcomeCountGen):
         """Returns the max outcome among all dice in this pool."""
         return self._max_outcome
 
-    def _pop_min(self,
-                 min_outcome) -> Generator[tuple['Pool', int, int], None, None]:
+    def _gen_min(self, min_outcome) -> GenGenerator:
         """Pops the given outcome from this pool, if it is the min outcome.
 
         Yields:
@@ -291,7 +304,7 @@ class Pool(OutcomeCountGen):
             net_weight: The weight of this incremental result.
         """
         if not self.outcomes():
-            yield self, 0, 1
+            yield self, (0,), 1
             return
         generators = [
             iter_die_pop_min(die, die_count, min_outcome)
@@ -322,13 +335,12 @@ class Pool(OutcomeCountGen):
                                0) + result_weight * popped_pool.denominator()
                 continue
 
-            yield popped_pool, result_count, result_weight
+            yield popped_pool, (result_count,), result_weight
 
         if skip_weight is not None:
-            yield empty_pool, sum(self.post_roll_counts()), skip_weight
+            yield Pool([]), (sum(self.post_roll_counts()),), skip_weight
 
-    def _pop_max(self,
-                 max_outcome) -> Generator[tuple['Pool', int, int], None, None]:
+    def _gen_max(self, max_outcome) -> GenGenerator:
         """Pops the given outcome from this pool, if it is the max outcome.
 
         Yields:
@@ -338,7 +350,7 @@ class Pool(OutcomeCountGen):
             net_weight: The weight of this incremental result.
         """
         if not self.outcomes():
-            yield self, 0, 1
+            yield self, (0,), 1
             return
         generators = [
             iter_die_pop_max(die, die_count, max_outcome)
@@ -369,10 +381,10 @@ class Pool(OutcomeCountGen):
                                0) + result_weight * popped_pool.denominator()
                 continue
 
-            yield popped_pool, result_count, result_weight
+            yield popped_pool, (result_count,), result_weight
 
         if skip_weight is not None:
-            yield empty_pool, sum(self.post_roll_counts()), skip_weight
+            yield Pool([]), (sum(self.post_roll_counts()),), skip_weight
 
     def lowest(self, num_keep: int = 1, num_drop: int = 0) -> 'icepool.Die':
         """The lowest outcome or sum of the lowest outcomes in the pool.
@@ -594,7 +606,3 @@ def iter_die_pop_max(
     for num_rolled, weight in enumerate(comb_row):
         num_remain = num_dice - num_rolled
         yield popped_die, num_remain, num_rolled, weight
-
-
-empty_pool = Pool([])
-"""Shared empty pool instance."""
\ No newline at end of file
